@@ -42,19 +42,35 @@ UiController::UiController( Ui *ui ) :
       homeLocation, SIGNAL( becomeValid() ),
       this, SLOT( setHomeButtonValid() )
   );
+  connect(
+      homeLocation, SIGNAL( becomeInValid() ),
+      this, SLOT( setHomeButtonInValid() )
+  );
   connect(
       homeLocation, SIGNAL( becomeValid() ),
       locations, SLOT( saveLocation() )
       );
+  connect(
+      homeLocation, SIGNAL( busy( bool ) ),
+      ui, SLOT( setBusy( bool ) )
+      );
 
   connect(
       workLocation, SIGNAL( becomeValid() ),
       this, SLOT( setWorkButtonValid() )
   );
+  connect(
+      workLocation, SIGNAL( becomeInValid() ),
+      this, SLOT( setWorkButtonInValid() )
+  );
   connect(
       workLocation, SIGNAL( becomeValid() ),
       locations, SLOT( saveLocation() )
       );
+  connect(
+      workLocation, SIGNAL( busy( bool ) ),
+      ui, SLOT( setBusy( bool ) )
+      );
 
   m_destination.append( homeLocation );
   m_destination.append( workLocation );
@@ -74,27 +90,37 @@ UiController::~UiController()
 {
 }
 
+void UiController::setHomeButtonInValid()
+{
+  qDebug() << "setting home button invalid";
+  setButtonValid( Ui::HomeButtonId, false );
+}
+
 void UiController::setHomeButtonValid()
 {
   qDebug() << "setting home button valid";
-  setButtonValid( Ui::HomeButtonId );
+  setButtonValid( Ui::HomeButtonId, true );
+}
+
+void UiController::setWorkButtonInValid()
+{
+  qDebug() << "setting work button invalid";
+  setButtonValid( Ui::WorkButtonId, false );
 }
 
 void UiController::setWorkButtonValid()
 {
   qDebug() << "setting work button valid";
-  setButtonValid( Ui::WorkButtonId );
+  setButtonValid( Ui::WorkButtonId, true );
 }
 
-void UiController::setButtonValid( int id )
+void UiController::setButtonValid( int id, bool isValid )
 {
-  m_ui->m_destinationButtons->button( id )->setEnabled(true);
+  m_ui->m_destinationButtons->button( id )->setEnabled( isValid );
 }
 
 void UiController::changeDestination( int id )
 {
-  qDebug() << "Destination button "+QString::number(id)+" clicked";
-
   bool destinationHasChanged = ( m_currentDestination != id );
   qDebug() << "Destination has changed=" << destinationHasChanged;
   if ( destinationHasChanged ) {
@@ -109,8 +135,6 @@ void UiController::changeDestination( int id )
 
 void UiController::changeRoute( int id )
 {
-  qDebug() << "Route button "+QString::number(id)+" clicked";
-
   bool routeHasChanged = ( m_currentRoute != id );
   if ( routeHasChanged ) {
     displayRouteDetail( id );
@@ -127,15 +151,20 @@ void UiController::displayRouteDetail( int id )
 
     int row=0;
     foreach( LegData thisLegData, legDataList ) {
+      QString thisHow = thisLegData.m_how;
+
+      bool thisIsLine = ( thisHow == "LINE" );
+      if ( thisIsLine ) {
+        thisHow = thisLegData.m_lineCode;
+      }
 
       QStringList tableStrings;
       tableStrings
-        << thisLegData.m_how
+        << thisHow
         << thisLegData.m_tripTime
         << thisLegData.m_tripDistance
         << thisLegData.m_departureTime
-        << thisLegData.m_arrivalTime
-        << thisLegData.m_lineCode;
+        << thisLegData.m_arrivalTime;
 
       int col=0;
       foreach( QString thisString, tableStrings ) {
